@@ -1279,8 +1279,9 @@ while (defined ($lineFromSource = <SRC>) || defined ($separatedLines[0]))
     }
 
     # now do the following until we get to </lexelt>
-    if ( defined @instanceArrayXml ) { undef @instanceArrayXml; }
-    if ( defined @instanceArrayCount ) { undef @instanceArrayCount; }
+# removed by tdp oct 3, 2015 due to perl deprecation of defined @array
+#    if ( defined @instanceArrayXml ) { undef @instanceArrayXml; }
+#    if ( defined @instanceArrayCount ) { undef @instanceArrayCount; }
 
     $instanceStringXml = "";
     $instanceStringCount = "";
@@ -1740,7 +1741,7 @@ sub showHelp
 sub showVersion
 {
 #    print STDERR "preprocess.pl  -  Version 0.3\n";
-    print  '$Id: preprocess.pl,v 1.8 2008/03/29 20:52:30 tpederse Exp $';     
+    print  '$Id: preprocess.pl,v 1.9 2015/10/03 14:05:57 tpederse Exp $';     
     print  "\nFormat and clean a Senseval-2 data file\n";
 #    print STDERR "Copyright (C) 2001-2003, Ted Pedersen & Satanjeev Banerjee\n";
 #    print STDERR "Date of Last Update: May 10, 2003 by TDP\n";
